==> nextcloud-14.0.13.zip: nextcloud/apps/files/l10n/is.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Gagnageymsla ekki tiltæk í augnablikinu",
    "Storage invalid" : "Ógild geymsla",
    "Unknown error" : "Óþekkt villa",
    "All files" : "Allar skrár",
    "Recent" : "Nýlegt",
    "Favorites" : "Eftirlæti",
    "File could not be found" : "Skrá finnst ekki",
    "Move or copy" : "Færa eða afrita",
    "Download" : "Niðurhal",
    "Delete" : "Eyða",
    "Home" : "Heim",
    "Close" : "Loka",
    "Could not create folder \"{dir}\"" : "Gat ekki búið til möppuna \"{dir}\"",
    "This will stop your current uploads." : "Þetta mun stöðva núverandi innsendingar þínar.",
    "Upload cancelled." : "Hætt við innsendingu.",
    "Processing files …" : "Vinn með skrár …",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Tókst ekki að hlaða inn {filename} þar sem þetta er mappa eða er 0 bæti",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ekki nægilegt laust pláss, þú ert að senda inn {size1} en einungis {size2} eru eftir",
    "Target folder \"{dir}\" does not exist any more" : "Markmappan \"{dir}\" er ekki lengur til",
    "Not enough free space" : "Ekki nægilegt pláss",
    "An unknown error has occurred" : "Óþekkt villa kom upp",
    "Uploading …" : "Sendi inn …",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} af {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Innsending á þessu atriði er ekki studd",
    "Target folder does not exist any more" : "Markmappan er ekki lengur til",
    "Error when assembling chunks, status code {status}" : "Villa við að setja búta saman, stöðukóði {status}",
    "Actions" : "Aðgerðir",
    "Rename" : "Endurnefna",
    "Copy" : "Afrita",
    "Choose target folder" : "Veldu úttaksmöppu",
    "Open" : "Opna",
    "Disconnect storage" : "Aftengja geymslu",
    "Unshare" : "Hætta deilingu",
    "Could not load info for file \"{file}\"" : "Gat ekki lesið upplýsingar um skrána \"{file}\"",
    "Files" : "Skrár",
    "Details" : "Nánar",
    "Select" : "Velja",
    "Pending" : "Í bið",
    "Unable to determine date" : "Tókst ekki að ákvarða dagsetningu",
    "This operation is forbidden" : "Þessi aðgerð er bönnuð",
    "This directory is unavailable, please check the logs or contact the administrator" : "Þessi mappa er ekki tiltæk, athugaðu atvikaskrár eða hafðu samband við kerfissjóra",
    "Could not move \"{file}\", target exists" : "Gat ekki fært \"{file}\", markskrá er til",
    "Could not move \"{file}\"" : "Gat ekki fært \"{file}\"",
    "copy" : "afrit",
    "Could not copy \"{file}\", target exists" : "Gat ekki afritað \"{file}\", markskrá er til",
    "Could not copy \"{file}\"" : "Gat ekki afritað \"{file}\"",
    "Copied {origin} inside {destination}" : "Afritaði {origin} inn í {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Afritaði {origin} og {nbfiles} aðrar skrár inn í {destination}",
    "{newName} already exists" : "{newName} er þegar til",
    "Could not rename \"{fileName}\", it does not exist any more" : "Gat ekki endurnefnt \"{fileName}\", það er ekki lengur til staðar",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Heitið \"{targetName}\" er nú þegar notað í \"{dir}\" möppunni. Veldu eitthvað annað nafn.",
    "Could not rename \"{fileName}\"" : "Gat ekki endurnefnt \"{fileName}\"",
    "Could not create file \"{file}\"" : "Gat ekki búið til skrána \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Gat ekki búið til skrána \"{file}\" vegna þess að hún er þegar til",
    "Could not create folder \"{dir}\" because it already exists" : "Gat ekki búið til möppuna \"{dir}\" vegna þess að hún er þegar til",
    "Error deleting file \"{fileName}\"." : "Villa við að eyða skránni \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Engar leitarniðurstöður í öðrum möppum fyrir {tag}{filter}{endtag}",
    "Name" : "Heiti",
    "Size" : "Stærð",
    "Modified" : "Breytt",
    "_%n folder_::_%n folders_" : ["%n mappa","%n möppur"],
    "_%n file_::_%n files_" : ["%n skrá","%n skrár"],
    "{dirs} and {files}" : "{dirs} og {files}",
    "_including %n hidden_::_including %n hidden_" : ["þar á meðal %n falin","þar á meðal %n faldar"],
    "You don’t have permission to upload or create files here" : "Þú hefur ekki heimild til að hlaða inn eða búa til skjöl hér",
    "_Uploading %n file_::_Uploading %n files_" : ["Sendi inn %n skrá","Sendi inn %n skrár"],
    "New" : "Nýtt",
    "Select file range" : "Veldu skráasvið",
    "{used} of {quota} used" : "{used} af {quota} notað",
    "{used} used" : "{used} notað",
    "\"{name}\" is an invalid file name." : "\"{name}\" er ógilt skráarheiti.",
    "File name cannot be empty." : "Heiti skráar má ekki vera tómt",
    "\"/\" is not allowed inside a file name." : "\"/\" er er ekki leyfilegt innan í skráarheiti.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" er ógild skráartegund",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Geymslupláss {owner} er fullt, ekki er lengur hægt að uppfæra eða samstilla skrár!",
    "Your storage is full, files can not be updated or synced anymore!" : "Geymsluplássið þitt er fullt, ekki er lengur hægt að uppfæra eða samstilla skrár!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Geymslupláss {owner} er næstum fullt ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Geymsluplássið þitt er næstum fullt ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["samsvarar '{filter}'","samsvara '{filter}'"],
    "View in folder" : "Skoða í möppu",
    "Copied!" : "Afritað!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Afrita beinan tengil (virkar bara fyrir notendur sem eiga aðgang að þessari skrá/möppu)",
    "Path" : "Slóð",
    "_%n byte_::_%n bytes_" : ["%n bæti","%n bæti"],
    "Favorited" : "Sett í eftirlæti",
    "Favorite" : "Eftirlæti",
    "You can only favorite a single file or folder at a time" : "Þú getur aðeins bætt einni skrá eða möppu í einu í eftilæti",
    "New folder" : "Ný mappa",
    "Upload file" : "Senda inn skrá",
    "Not favorited" : "Ekki í eftirlætum",
    "Remove from favorites" : "Fjarlægja úr eftirlætum",
    "Add to favorites" : "Bæta í eftirlæti",
    "An error occurred while trying to update the tags" : "Villa kom upp við að reyna að uppfæra merkin",
    "Added to favorites" : "Bætt í eftirlæti",
    "Removed from favorites" : "Fjarlægt úr eftirlætum",
    "You added {file} to your favorites" : "Þú bættir {file} í eftirlætin þín",
    "You removed {file} from your favorites" : "Þú fjarlægðir {file} úr eftirlætunum þínum",
    "File changes" : "Skráarbreytingar",
    "Created by {user}" : "Búið til af {user}",
    "Changed by {user}" : "Breytt af {user}",
    "Deleted by {user}" : "Eytt af {user}",
    "Restored by {user}" : "Endurheimt af {user}",
    "Renamed by {user}" : "Endurnefnt af {user}",
    "Moved by {user}" : "Fært af {user}",
    "\"remote user\"" : "\"fjartengdur notandi\"",
    "You created {file}" : "Þú bjóst til {file}",
    "You created an encrypted file in {file}" : "Þú bjóst til dulritaða skrá í {file}",
    "{user} created {file}" : "{user} bjó til {file}",
    "{user} created an encrypted file in {file}" : "{user} bjó til dulritaða skrá í {file}",
    "{file} was created in a public folder" : "{file} var búin til í opinni möppu",
    "You changed {file}" : "Þú breyttir {file}",
    "You changed an encrypted file in {file}" : "Þú breyttir dulritaðri skrá í {file}",
    "{user} changed {file}" : "{user} breytti {file}",
    "{user} changed an encrypted file in {file}" : "{user} breytti dulritaðri skrá í {file}",
    "You deleted {file}" : "Þú eyddir {file}",
    "You deleted an encrypted file in {file}" : "Þú eyddir dulritaðri skrá í {file}",
    "{user} deleted {file}" : "{user} eyddi {file}",
    "{user} deleted an encrypted file in {file}" : "{user} eyddi dulritaðri skrá í {file}",
    "You restored {file}" : "Þú endurheimtir {file}",
    "{user} restored {file}" : "{user} endurheimti {file}",
    "You renamed {oldfile} to {newfile}" : "Þú endurnefndir {oldfile} sem {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} endurnefndi {oldfile} sem {newfile}",
    "You moved {oldfile} to {newfile}" : "Þú færðir {oldfile} í {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} færði {oldfile} í {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Skrá var bætt við eða hún fjarlægð úr <strong>eftirlætum</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Skrá eða möppu hefur verið <strong>breytt</strong> eða verið <strong>endurnefnt</strong>",
    "A new file or folder has been <strong>created</strong>" : "Skjal eða mappa hefur verið <strong>búin til</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Skjali eða möppu hefur verið  <strong>eytt</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Takmarka tilkynningar um gerð og breytingar á <strong>eftirlætisskrám</strong> <em>(einungis streymi)</em>",
    "A file or folder has been <strong>restored</strong>" : "Skjal eða mappa hefur verið <strong>endurheimt</strong>",
    "Unlimited" : "Ótakmarkað",
    "Upload (max. %s)" : "Senda inn (hám. %s)",
    "File Management" : "Skráastjórnun",
    "%s used" : "%s notað",
    "%1$s of %2$s used" : "%1$s af %2$s notað",
    "Settings" : "Stillingar",
    "Show hidden files" : "Sýna faldar skrár",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Notaðu þetta vistfang til að <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">nálgast skrárnar þínar með WebDAV</a>",
    "Toggle grid view" : "Víxla reitasýn af/á",
    "No files in here" : "Engar skrár hér",
    "Upload some content or sync with your devices!" : "Sendu inn eitthvað efni eða samstilltu við tækin þín!",
    "No entries found in this folder" : "Engar skrár fundust í þessari möppu",
    "Select all" : "Velja allt",
    "Upload too large" : "Innsend skrá er of stór",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Skrárnar sem þú ert að senda inn eru stærri en hámarks innsendingarstærð á þessum netþjóni.",
    "No favorites yet" : "Engin eftirlæti ennþá",
    "Files and folders you mark as favorite will show up here" : "Skrár og möppur sem þú merkir sem eftirlæti birtast hér",
    "Tags" : "Merki",
    "Deleted files" : "Eyddar skrár",
    "Shares" : "Sameignir",
    "Shared with others" : "Deilt með öðrum",
    "Shared with you" : "Deilt með þér",
    "Shared by link" : "Deilt með tengli",
    "Deleted shares" : "Eyddar sameignir",
    "Text file" : "Textaskrá",
    "New text file.txt" : "Ný textaskrá.txt",
    "Target folder" : "Markmappa",
    "File handling" : "Meðhöndlun skráar",
    "Maximum upload size" : "Hámarksstærð innsendingar",
    "max. possible: " : "hámark mögulegt: ",
    "Save" : "Vista",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Með PHP-FPM getur það tekið 5 mínútur fyrir breytingar að verða virkar.",
    "Missing permissions to edit from here." : "Vantar heimildir til að breyta einhverju héðan.",
    "%s of %s used" : "%s af %s notað",
    "Cancel upload" : "Hætta við innsendingu",
    "%1$s%% of %2$s used" : "%1$s%% af %2$s notað"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");

==> nextcloud-15.0.7.zip: nextcloud/apps/files/l10n/is.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Gagnageymsla ekki tiltæk í augnablikinu",
    "Storage invalid" : "Ógild geymsla",
    "Unknown error" : "Óþekkt villa",
    "All files" : "Allar skrár",
    "Recent" : "Nýlegt",
    "Favorites" : "Eftirlæti",
    "File could not be found" : "Skrá finnst ekki",
    "Move or copy" : "Færa eða afrita",
    "Download" : "Niðurhal",
    "Delete" : "Eyða",
    "Home" : "Heim",
    "Close" : "Loka",
    "Could not create folder \"{dir}\"" : "Gat ekki búið til möppuna \"{dir}\"",
    "This will stop your current uploads." : "Þetta mun stöðva núverandi innsendingar þínar.",
    "Upload cancelled." : "Hætt við innsendingu.",
    "Processing files …" : "Vinn með skrár …",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Tókst ekki að hlaða inn {filename} þar sem þetta er mappa eða er 0 bæti",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ekki nægilegt laust pláss, þú ert að senda inn {size1} en einungis {size2} eru eftir",
    "Target folder \"{dir}\" does not exist any more" : "Markmappan \"{dir}\" er ekki lengur til",
    "Not enough free space" : "Ekki nægilegt pláss",
    "An unknown error has occurred" : "Óþekkt villa kom upp",
    "Uploading …" : "Sendi inn …",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} af {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Innsending á þessu atriði er ekki studd",
    "Target folder does not exist any more" : "Markmappan er ekki lengur til",
    "Error when assembling chunks, status code {status}" : "Villa við að setja búta saman, stöðukóði {status}",
    "Actions" : "Aðgerðir",
    "Rename" : "Endurnefna",
    "Copy" : "Afrita",
    "Choose target folder" : "Veldu úttaksmöppu",
    "Open" : "Opna",
    "Disconnect storage" : "Aftengja geymslu",
    "Unshare" : "Hætta deilingu",
    "Could not load info for file \"{file}\"" : "Gat ekki lesið upplýsingar um skrána \"{file}\"",
    "Files" : "Skrár",
    "Details" : "Nánar",
    "Select" : "Velja",
    "Pending" : "Í bið",
    "Unable to determine date" : "Tókst ekki að ákvarða dagsetningu",
    "This operation is forbidden" : "Þessi aðgerð er bönnuð",
    "This directory is unavailable, please check the logs or contact the administrator" : "Þessi mappa er ekki tiltæk, athugaðu atvikaskrár eða hafðu samband við kerfissjóra",
    "Could not move \"{file}\", target exists" : "Gat ekki fært \"{file}\", markskrá er til",
    "Could not move \"{file}\"" : "Gat ekki fært \"{file}\"",
    "copy" : "afrit",
    "Could not copy \"{file}\", target exists" : "Gat ekki afritað \"{file}\", markskrá er til",
    "Could not copy \"{file}\"" : "Gat ekki afritað \"{file}\"",
    "Copied {origin} inside {destination}" : "Afritaði {origin} inn í {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Afritaði {origin} og {nbfiles} aðrar skrár inn í {destination}",
    "{newName} already exists" : "{newName} er þegar til",
    "Could not rename \"{fileName}\", it does not exist any more" : "Gat ekki endurnefnt \"{fileName}\", það er ekki lengur til staðar",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Heitið \"{targetName}\" er nú þegar notað í \"{dir}\" möppunni. Veldu eitthvað annað nafn.",
    "Could not rename \"{fileName}\"" : "Gat ekki endurnefnt \"{fileName}\"",
    "Could not create file \"{file}\"" : "Gat ekki búið til skrána \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Gat ekki búið til skrána \"{file}\" vegna þess að hún er þegar til",
    "Could not create folder \"{dir}\" because it already exists" : "Gat ekki búið til möppuna \"{dir}\" vegna þess að hún er þegar til",
    "Error deleting file \"{fileName}\"." : "Villa við að eyða skránni \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Engar leitarniðurstöður í öðrum möppum fyrir {tag}{filter}{endtag}",
    "Name" : "Heiti",
    "Size" : "Stærð",
    "Modified" : "Breytt",
    "_%n folder_::_%n folders_" : ["%n mappa","%n möppur"],
    "_%n file_::_%n files_" : ["%n skrá","%n skrár"],
    "{dirs} and {files}" : "{dirs} og {files}",
    "_including %n hidden_::_including %n hidden_" : ["þar á meðal %n falin","þar á meðal %n faldar"],
    "You don’t have permission to upload or create files here" : "Þú hefur ekki heimild til að hlaða inn eða búa til skjöl hér",
    "_Uploading %n file_::_Uploading %n files_" : ["Sendi inn %n skrá","Sendi inn %n skrár"],
    "New" : "Nýtt",
    "Select file range" : "Veldu skráasvið",
    "{used} of {quota} used" : "{used} af {quota} notað",
    "{used} used" : "{used} notað",
    "\"{name}\" is an invalid file name." : "\"{name}\" er ógilt skráarheiti.",
    "File name cannot be empty." : "Heiti skráar má ekki vera tómt",
    "\"/\" is not allowed inside a file name." : "\"/\" er er ekki leyfilegt innan í skráarheiti.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" er ógild skráartegund",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Geymslupláss {owner} er fullt, ekki er lengur hægt að uppfæra eða samstilla skrár!",
    "Your storage is full, files can not be updated or synced anymore!" : "Geymsluplássið þitt er fullt, ekki er lengur hægt að uppfæra eða samstilla skrár!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Geymslupláss {owner} er næstum fullt ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Geymsluplássið þitt er næstum fullt ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["samsvarar '{filter}'","samsvara '{filter}'"],
    "View in folder" : "Skoða í möppu",
    "Copied!" : "Afritað!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Afrita beinan tengil (virkar bara fyrir notendur sem eiga aðgang að þessari skrá/möppu)",
    "Path" : "Slóð",
    "_%n byte_::_%n bytes_" : ["%n bæti","%n bæti"],
    "Favorited" : "Sett í eftirlæti",
    "Favorite" : "Eftirlæti",
    "You can only favorite a single file or folder at a time" : "Þú getur aðeins bætt einni skrá eða möppu í einu í eftilæti",
    "New folder" : "Ný mappa",
    "Upload file" : "Senda inn skrá",
    "Not favorited" : "Ekki í eftirlætum",
    "Remove from favorites" : "Fjarlægja úr eftirlætum",
    "Add to favorites" : "Bæta í eftirlæti",
    "An error occurred while trying to update the tags" : "Villa kom upp við að reyna að uppfæra merkin",
    "Added to favorites" : "Bætt í eftirlæti",
    "Removed from favorites" : "Fjarlægt úr eftirlætum",
    "You added {file} to your favorites" : "Þú bættir {file} í eftirlætin þín",
    "You removed {file} from your favorites" : "Þú fjarlægðir {file} úr eftirlætunum þínum",
    "File changes" : "Skráarbreytingar",
    "Created by {user}" : "Búið til af {user}",
    "Changed by {user}" : "Breytt af {user}",
    "Deleted by {user}" : "Eytt af {user}",
    "Restored by {user}" : "Endurheimt af {user}",
    "Renamed by {user}" : "Endurnefnt af {user}",
    "Moved by {user}" : "Fært af {user}",
    "\"remote user\"" : "\"fjartengdur notandi\"",
    "You created {file}" : "Þú bjóst til {file}",
    "You created an encrypted file in {file}" : "Þú bjóst til dulritaða skrá í {file}",
    "{user} created {file}" : "{user} bjó til {file}",
    "{user} created an encrypted file in {file}" : "{user} bjó til dulritaða skrá í {file}",
    "{file} was created in a public folder" : "{file} var búin til í opinni möppu",
    "You changed {file}" : "Þú breyttir {file}",
    "You changed an encrypted file in {file}" : "Þú breyttir dulritaðri skrá í {file}",
    "{user} changed {file}" : "{user} breytti {file}",
    "{user} changed an encrypted file in {file}" : "{user} breytti dulritaðri skrá í {file}",
    "You deleted {file}" : "Þú eyddir {file}",
    "You deleted an encrypted file in {file}" : "Þú eyddir dulritaðri skrá í {file}",
    "{user} deleted {file}" : "{user} eyddi {file}",
    "{user} deleted an encrypted file in {file}" : "{user} eyddi dulritaðri skrá í {file}",
    "You restored {file}" : "Þú endurheimtir {file}",
    "{user} restored {file}" : "{user} endurheimti {file}",
    "You renamed {oldfile} to {newfile}" : "Þú endurnefndir {oldfile} sem {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} endurnefndi {oldfile} sem {newfile}",
    "You moved {oldfile} to {newfile}" : "Þú færðir {oldfile} í {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} færði {oldfile} í {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Skrá var bætt við eða hún fjarlægð úr <strong>eftirlætum</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Skrá eða möppu hefur verið <strong>breytt</strong> eða verið <strong>endurnefnt</strong>",
    "A new file or folder has been <strong>created</strong>" : "Skjal eða mappa hefur verið <strong>búin til</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Skjali eða möppu hefur verið  <strong>eytt</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Takmarka tilkynningar um gerð og breytingar á <strong>eftirlætisskrám</strong> <em>(einungis streymi)</em>",
    "A file or folder has been <strong>restored</strong>" : "Skjal eða mappa hefur verið <strong>endurheimt</strong>",
    "Unlimited" : "Ótakmarkað",
    "Upload (max. %s)" : "Senda inn (hám. %s)",
    "File Management" : "Skráastjórnun",
    "%s of %s used" : "%s af %s notað",
    "%1$s%% of %2$s used" : "%1$s%% af %2$s notað",
    "%s used" : "%s notað",
    "Settings" : "Stillingar",
    "Show hidden files" : "Sýna faldar skrár",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Notaðu þetta vistfang til að <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">nálgast skrárnar þínar með WebDAV</a>",
    "Toggle grid view" : "Víxla reitasýn af/á",
    "No files in here" : "Engar skrár hér",
    "Upload some content or sync with your devices!" : "Sendu inn eitthvað efni eða samstilltu við tækin þín!",
    "No entries found in this folder" : "Engar skrár fundust í þessari möppu",
    "Select all" : "Velja allt",
    "Upload too large" : "Innsend skrá er of stór",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Skrárnar sem þú ert að senda inn eru stærri en hámarks innsendingarstærð á þessum netþjóni.",
    "No favorites yet" : "Engin eftirlæti ennþá",
    "Files and folders you mark as favorite will show up here" : "Skrár og möppur sem þú merkir sem eftirlæti birtast hér",
    "Tags" : "Merki",
    "Deleted files" : "Eyddar skrár",
    "Shares" : "Sameignir",
    "Shared with others" : "Deilt með öðrum",
    "Shared with you" : "Deilt með þér",
    "Shared by link" : "Deilt með tengli",
    "Deleted shares" : "Eyddar sameignir",
    "Text file" : "Textaskrá",
    "New text file.txt" : "Ný textaskrá.txt",
    "Target folder" : "Markmappa",
    "File handling" : "Meðhöndlun skráar",
    "Maximum upload size" : "Hámarksstærð innsendingar",
    "max. possible: " : "hámark mögulegt: ",
    "Save" : "Vista",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Með PHP-FPM getur það tekið 5 mínútur fyrir breytingar að verða virkar.",
    "Missing permissions to edit from here." : "Vantar heimildir til að breyta einhverju héðan.",
    "Cancel upload" : "Hætta við innsendingu",
    "%1$s of %2$s used" : "%1$s af %2$s notað"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
